##  Prerequisites
  * In SAP LeanIX:
    * Administrator access to your workspace.
    * An API token. This is only applicable if you want to use Smart Links in Confluence. To get an API token, create a technical user. Learn how in the topic [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").
  * Allow third-party cookies in your browser. To allow third-party cookies, you may need to manually add your SAP LeanIX instance (for example, your-subdomain.leanix.net) to your browser privacy settings.
  * Confluence administrator access.
